@@ -6,10 +6,10 @@ from django_cron.models import CronJobLog
 class CronJobLogAdmin(admin.ModelAdmin):
     class Meta:
         model = CronJobLog
-  
+
     search_fields = ('code', 'message')
     ordering = ('-start_time',)
-    list_display = ('code', 'start_time', 'is_success')
+    list_display = ('code', 'start_time', 'end_time', 'is_success')
     list_filter = ('code', 'start_time', 'is_success')
 
     def get_readonly_fields(self, request, obj=None):
