@@ -1,7 +1,6 @@
 from django.conf import settings
-from django_cron import CronJobBase, Schedule
+from django_cron import CronJobBase, Schedule, get_class
 from django_cron.models import CronJobLog
-from django_cron.management.commands.runcrons import get_class
 
 from django_common.helper import send_mail
 
@@ -44,7 +43,6 @@ class FailedRunsNotificationCronJob(CronJobBase):
                     message += 'Job ran at %s : \n\n %s \n\n' % (job.start_time, job.message)
 
             if failures == min_failures:
-
                 send_mail(
                     '%s%s failed %s times in a row!' % (FAILED_RUNS_CRONJOB_EMAIL_PREFIX, cron.code, \
                         min_failures), message,
